@@ -37,9 +37,7 @@
  * #ClutterClone is available since Clutter 1.0
  */
 
-#ifdef HAVE_CONFIG_H
 #include "clutter-build-config.h"
-#endif
 
 #define CLUTTER_ENABLE_EXPERIMENTAL_API
 #include "clutter-actor-private.h"
@@ -54,6 +52,7 @@
 struct _ClutterClonePrivate
 {
   ClutterActor *clone_source;
+  gulong source_destroy_id;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (ClutterClone, clutter_clone, CLUTTER_TYPE_ACTOR)
@@ -253,6 +252,13 @@ clutter_clone_allocate (ClutterActor           *self,
   if (priv->clone_source == NULL)
     return;
 
+  /* ClutterActor delays allocating until the actor is shown; however
+   * we cannot paint it correctly in that case, so force an allocation.
+   */
+  if (clutter_actor_get_parent (priv->clone_source) != NULL &&
+      !clutter_actor_has_allocation (priv->clone_source))
+    clutter_actor_allocate_preferred_size (priv->clone_source, flags);
+
 #if 0
   /* XXX - this is wrong: ClutterClone cannot clone unparented
    * actors, as it will break all invariants
@@ -376,6 +382,13 @@ clutter_clone_new (ClutterActor *source)
   return g_object_new (CLUTTER_TYPE_CLONE, "source", source,  NULL);
 }
 
+static void
+on_source_destroyed (ClutterActor *source,
+                     ClutterClone *self)
+{
+  clutter_clone_set_source_internal (self, NULL);
+}
+
 static void
 clutter_clone_set_source_internal (ClutterClone *self,
 				   ClutterActor *source)
@@ -387,6 +400,8 @@ clutter_clone_set_source_internal (ClutterClone *self,
 
   if (priv->clone_source != NULL)
     {
+      g_signal_handler_disconnect (priv->clone_source, priv->source_destroy_id);
+      priv->source_destroy_id = 0;
       _clutter_actor_detach_clone (priv->clone_source, CLUTTER_ACTOR (self));
       g_object_unref (priv->clone_source);
       priv->clone_source = NULL;
@@ -396,6 +411,8 @@ clutter_clone_set_source_internal (ClutterClone *self,
     {
       priv->clone_source = g_object_ref (source);
       _clutter_actor_attach_clone (priv->clone_source, CLUTTER_ACTOR (self));
+      priv->source_destroy_id = g_signal_connect (priv->clone_source, "destroy",
+                                                  G_CALLBACK (on_source_destroyed), self);
     }
 
   g_object_notify_by_pspec (G_OBJECT (self), obj_props[PROP_SOURCE]);
