@@ -91,22 +91,14 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (ClutterDeviceManager,
                                      clutter_device_manager,
                                      G_TYPE_OBJECT)
 
-G_DEFINE_INTERFACE (ClutterEventExtender,
-                    clutter_event_extender,
-                    CLUTTER_TYPE_DEVICE_MANAGER)
-
-static void
-clutter_event_extender_default_init (ClutterEventExtenderInterface *iface)
-{
-}
-
 static void
 clutter_device_manager_set_property (GObject      *gobject,
                                      guint         prop_id,
                                      const GValue *value,
                                      GParamSpec   *pspec)
 {
-  ClutterDeviceManagerPrivate *priv = CLUTTER_DEVICE_MANAGER (gobject)->priv;
+  ClutterDeviceManager *self = CLUTTER_DEVICE_MANAGER (gobject);
+  ClutterDeviceManagerPrivate *priv = clutter_device_manager_get_instance_private (self);
 
   switch (prop_id)
     {
@@ -125,7 +117,8 @@ clutter_device_manager_get_property (GObject    *gobject,
                                      GValue     *value,
                                      GParamSpec *pspec)
 {
-  ClutterDeviceManagerPrivate *priv = CLUTTER_DEVICE_MANAGER (gobject)->priv;
+  ClutterDeviceManager *self = CLUTTER_DEVICE_MANAGER (gobject);
+  ClutterDeviceManagerPrivate *priv = clutter_device_manager_get_instance_private (self);
 
   switch (prop_id)
     {
@@ -289,6 +282,7 @@ clutter_device_manager_class_init (ClutterDeviceManagerClass *klass)
    * @manager: the #ClutterDeviceManager that emitted the signal
    * @device: the core pointer #ClutterInputDevice
    * @timeout_type: the type of timeout #ClutterPointerA11yTimeoutType
+   * @clicked: %TRUE if the timeout finished and triggered a click
    *
    * The ::ptr-a11y-timeout-stopped signal is emitted when a running
    * pointer accessibility timeout delay is stopped, either because
@@ -300,16 +294,16 @@ clutter_device_manager_class_init (ClutterDeviceManagerClass *klass)
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0, NULL, NULL,
-                  _clutter_marshal_VOID__OBJECT_FLAGS,
-                  G_TYPE_NONE, 2,
+                  _clutter_marshal_VOID__OBJECT_FLAGS_BOOLEAN,
+                  G_TYPE_NONE, 3,
                   CLUTTER_TYPE_INPUT_DEVICE,
-                  CLUTTER_TYPE_POINTER_A11Y_TIMEOUT_TYPE);
+                  CLUTTER_TYPE_POINTER_A11Y_TIMEOUT_TYPE,
+                  G_TYPE_BOOLEAN);
 }
 
 static void
 clutter_device_manager_init (ClutterDeviceManager *self)
 {
-  self->priv = clutter_device_manager_get_instance_private (self);
 }
 
 /**
@@ -328,7 +322,7 @@ clutter_device_manager_get_default (void)
 {
   ClutterBackend *backend = clutter_get_default_backend ();
 
-  return backend->device_manager;
+  return CLUTTER_BACKEND_GET_CLASS (backend)->get_device_manager (backend);
 }
 
 /**
@@ -552,9 +546,11 @@ _clutter_device_manager_update_devices (ClutterDeviceManager *device_manager)
 ClutterBackend *
 _clutter_device_manager_get_backend (ClutterDeviceManager *manager)
 {
+  ClutterDeviceManagerPrivate *priv = clutter_device_manager_get_instance_private (manager);
+
   g_return_val_if_fail (CLUTTER_IS_DEVICE_MANAGER (manager), NULL);
 
-  return manager->priv->backend;
+  return priv->backend;
 }
 
 /**
@@ -611,6 +607,20 @@ _clutter_device_manager_compress_motion (ClutterDeviceManager *device_manager,
   manager_class->compress_motion (device_manager, event, to_discard);
 }
 
+void
+clutter_device_manager_ensure_a11y_state (ClutterDeviceManager *device_manager)
+{
+  ClutterInputDevice *core_pointer;
+
+  core_pointer = clutter_device_manager_get_core_device (device_manager,
+                                                         CLUTTER_POINTER_DEVICE);
+  if (core_pointer)
+    {
+      if (_clutter_is_input_pointer_a11y_enabled (core_pointer))
+        _clutter_input_pointer_a11y_add_device (core_pointer);
+    }
+}
+
 static gboolean
 are_kbd_a11y_settings_equal (ClutterKbdA11ySettings *a,
                              ClutterKbdA11ySettings *b)
@@ -623,13 +633,14 @@ clutter_device_manager_set_kbd_a11y_settings (ClutterDeviceManager   *device_man
                                               ClutterKbdA11ySettings *settings)
 {
   ClutterDeviceManagerClass *manager_class;
+  ClutterDeviceManagerPrivate *priv = clutter_device_manager_get_instance_private (device_manager);
 
   g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER (device_manager));
 
-  if (are_kbd_a11y_settings_equal (&device_manager->priv->kbd_a11y_settings, settings))
+  if (are_kbd_a11y_settings_equal (&priv->kbd_a11y_settings, settings))
     return;
 
-  device_manager->priv->kbd_a11y_settings = *settings;
+  priv->kbd_a11y_settings = *settings;
 
   manager_class = CLUTTER_DEVICE_MANAGER_GET_CLASS (device_manager);
   if (manager_class->apply_kbd_a11y_settings)
@@ -640,9 +651,11 @@ void
 clutter_device_manager_get_kbd_a11y_settings (ClutterDeviceManager   *device_manager,
                                               ClutterKbdA11ySettings *settings)
 {
+  ClutterDeviceManagerPrivate *priv = clutter_device_manager_get_instance_private (device_manager);
+
   g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER (device_manager));
 
-  *settings = device_manager->priv->kbd_a11y_settings;
+  *settings = priv->kbd_a11y_settings;
 }
 
 static gboolean
@@ -685,17 +698,20 @@ void
 clutter_device_manager_set_pointer_a11y_settings (ClutterDeviceManager       *device_manager,
                                                   ClutterPointerA11ySettings *settings)
 {
+  ClutterDeviceManagerPrivate *priv =
+    clutter_device_manager_get_instance_private (device_manager);
+
   g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER (device_manager));
 
-  if (are_pointer_a11y_settings_equal (&device_manager->priv->pointer_a11y_settings, settings))
+  if (are_pointer_a11y_settings_equal (&priv->pointer_a11y_settings, settings))
     return;
 
-  if (device_manager->priv->pointer_a11y_settings.controls == 0 && settings->controls != 0)
+  if (priv->pointer_a11y_settings.controls == 0 && settings->controls != 0)
     clutter_device_manager_enable_pointer_a11y (device_manager);
-  else if (device_manager->priv->pointer_a11y_settings.controls != 0 && settings->controls == 0)
+  else if (priv->pointer_a11y_settings.controls != 0 && settings->controls == 0)
     clutter_device_manager_disable_pointer_a11y (device_manager);
 
-  device_manager->priv->pointer_a11y_settings = *settings;
+  priv->pointer_a11y_settings = *settings;
 }
 
 /**
@@ -709,9 +725,12 @@ void
 clutter_device_manager_get_pointer_a11y_settings (ClutterDeviceManager       *device_manager,
                                                   ClutterPointerA11ySettings *settings)
 {
+  ClutterDeviceManagerPrivate *priv =
+    clutter_device_manager_get_instance_private (device_manager);
+
   g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER (device_manager));
 
-  *settings = device_manager->priv->pointer_a11y_settings;
+  *settings = priv->pointer_a11y_settings;
 }
 
 /**
@@ -725,7 +744,10 @@ void
 clutter_device_manager_set_pointer_a11y_dwell_click_type (ClutterDeviceManager             *device_manager,
                                                           ClutterPointerA11yDwellClickType  click_type)
 {
+  ClutterDeviceManagerPrivate *priv =
+    clutter_device_manager_get_instance_private (device_manager);
+
   g_return_if_fail (CLUTTER_IS_DEVICE_MANAGER (device_manager));
 
-  device_manager->priv->pointer_a11y_settings.dwell_click_type = click_type;
+  priv->pointer_a11y_settings.dwell_click_type = click_type;
 }
