@@ -55,8 +55,8 @@ test_blend_paint (TestState  *state,
 
   CoglHandle material;
   CoglPipeline *pipeline;
-  CoglBool status;
-  CoglError *error = NULL;
+  gboolean status;
+  GError *error = NULL;
   int y_off;
   int x_off;
 
@@ -230,8 +230,8 @@ test_tex_combine (TestState *state,
   CoglColor combine_const_color;
 
   CoglHandle material;
-  CoglBool status;
-  CoglError *error = NULL;
+  gboolean status;
+  GError *error = NULL;
   int y_off;
   int x_off;
 
