@@ -175,10 +175,6 @@ struct _MetaKms
 
 G_DEFINE_TYPE (MetaKms, meta_kms, G_TYPE_OBJECT)
 
-static void
-meta_kms_update_states_in_impl (MetaKms                  *kms,
-                                MetaKmsUpdateStatesFlags  flags);
-
 MetaKmsUpdate *
 meta_kms_ensure_pending_update (MetaKms *kms)
 {
@@ -194,6 +190,17 @@ meta_kms_get_pending_update (MetaKms *kms)
   return kms->pending_update;
 }
 
+static void
+meta_kms_predict_states_in_impl (MetaKms       *kms,
+                                 MetaKmsUpdate *update)
+{
+  meta_assert_in_kms_impl (kms);
+
+  g_list_foreach (kms->devices,
+                  (GFunc) meta_kms_device_predict_states_in_impl,
+                  update);
+}
+
 static gboolean
 meta_kms_update_process_in_impl (MetaKmsImpl  *impl,
                                  gpointer      user_data,
@@ -205,8 +212,7 @@ meta_kms_update_process_in_impl (MetaKmsImpl  *impl,
   ret = meta_kms_impl_process_update (impl, update, error);
 
   if (meta_kms_update_has_mode_set (update))
-    meta_kms_update_states_in_impl (meta_kms_impl_get_kms (impl),
-                                    META_KMS_UPDATE_STATES_FLAG_NONE);
+    meta_kms_predict_states_in_impl (meta_kms_impl_get_kms (impl), update);
 
   return ret;
 }
@@ -461,22 +467,16 @@ meta_kms_is_waiting_for_impl_task (MetaKms *kms)
 }
 
 static void
-meta_kms_update_states_in_impl (MetaKms                  *kms,
-                                MetaKmsUpdateStatesFlags  flags)
+meta_kms_update_states_in_impl (MetaKms *kms)
 {
-  GList *l;
-
   COGL_TRACE_BEGIN_SCOPED (MetaKmsUpdateStates,
                            "KMS (update states)");
 
   meta_assert_in_kms_impl (kms);
 
-  for (l = kms->devices; l; l = l->next)
-    {
-      MetaKmsDevice *device = l->data;
-
-      meta_kms_device_update_states_in_impl (device, flags);
-    }
+  g_list_foreach (kms->devices,
+                  (GFunc) meta_kms_device_update_states_in_impl,
+                  NULL);
 }
 
 static gboolean
@@ -485,22 +485,17 @@ update_states_in_impl (MetaKmsImpl  *impl,
                        GError      **error)
 {
   MetaKms *kms = meta_kms_impl_get_kms (impl);;
-  MetaKmsUpdateStatesFlags flags = GPOINTER_TO_UINT (user_data);
 
-  meta_kms_update_states_in_impl (kms, flags);
+  meta_kms_update_states_in_impl (kms);
 
   return TRUE;
 }
 
 static gboolean
-meta_kms_update_states_sync (MetaKms                   *kms,
-                             MetaKmsUpdateStatesFlags   flags,
-                             GError                   **error)
+meta_kms_update_states_sync (MetaKms  *kms,
+                             GError  **error)
 {
-  return meta_kms_run_impl_task_sync (kms,
-                                      update_states_in_impl,
-                                      GUINT_TO_POINTER (flags),
-                                      error);
+  return meta_kms_run_impl_task_sync (kms, update_states_in_impl, NULL, error);
 }
 
 static void
@@ -508,9 +503,7 @@ handle_hotplug_event (MetaKms *kms)
 {
   g_autoptr (GError) error = NULL;
 
-  if (!meta_kms_update_states_sync (kms,
-                                    META_KMS_UPDATE_STATES_FLAG_HOTPLUG,
-                                    &error))
+  if (!meta_kms_update_states_sync (kms, &error))
     g_warning ("Updating KMS state failed: %s", error->message);
 
   g_signal_emit (kms, signals[RESOURCES_CHANGED], 0);
