@@ -26,7 +26,8 @@
 #include "meta/meta-plugin.h"
 #include "meta/types.h"
 
-typedef enum {
+typedef enum
+{
   META_PLUGIN_NONE,
   META_PLUGIN_MINIMIZE,
   META_PLUGIN_MAP,
@@ -99,4 +100,6 @@ MetaInhibitShortcutsDialog *
   meta_plugin_manager_create_inhibit_shortcuts_dialog (MetaPluginManager *plugin_mgr,
                                                        MetaWindow        *window);
 
+void meta_plugin_manager_locate_pointer (MetaPluginManager *mgr);
+
 #endif
