@@ -28,6 +28,7 @@
 #include <string.h>
 
 #include "clutter/clutter.h"
+#include "meta/meta-backend.h"
 #include "meta/meta-background-actor.h"
 #include "meta/meta-background-group.h"
 #include "meta/meta-monitor-manager.h"
@@ -369,6 +370,67 @@ on_monitors_changed (MetaMonitorManager *monitor_manager,
   g_rand_free (rand);
 }
 
+static void
+init_keymap (MetaDefaultPlugin *self)
+{
+  g_autoptr (GError) error = NULL;
+  g_autoptr (GDBusProxy) proxy = NULL;
+  g_autoptr (GVariant) result = NULL;
+  g_autoptr (GVariant) props = NULL;
+  g_autofree char *x11_layout = NULL;
+  g_autofree char *x11_options = NULL;
+  g_autofree char *x11_variant = NULL;
+
+  proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+                                         G_DBUS_PROXY_FLAGS_NONE,
+                                         NULL,
+                                         "org.freedesktop.locale1",
+                                         "/org/freedesktop/locale1",
+                                         "org.freedesktop.DBus.Properties",
+                                         NULL,
+                                         &error);
+  if (!proxy)
+    {
+      g_message ("Failed to acquire org.freedesktop.locale1 proxy: %s, "
+                 "probably running in CI",
+                 error->message);
+      return;
+    }
+
+  result = g_dbus_proxy_call_sync (proxy,
+                                   "GetAll",
+                                   g_variant_new ("(s)",
+                                                  "org.freedesktop.locale1"),
+                                   G_DBUS_CALL_FLAGS_NONE,
+                                   100,
+                                   NULL,
+                                   &error);
+  if (!result)
+    {
+      g_warning ("Failed to retrieve locale properties: %s", error->message);
+      return;
+    }
+
+  props = g_variant_get_child_value (result, 0);
+  if (!props)
+    {
+      g_warning ("No locale properties found");
+      return;
+    }
+
+  if (!g_variant_lookup (props, "X11Layout", "s", &x11_layout))
+    x11_layout = g_strdup ("us");
+
+  if (!g_variant_lookup (props, "X11Options", "s", &x11_options))
+    x11_options = g_strdup ("");
+
+  if (!g_variant_lookup (props, "X11Variant", "s", &x11_variant))
+    x11_variant = g_strdup ("");
+
+  meta_backend_set_keymap (meta_get_backend (),
+                           x11_layout, x11_variant, x11_options);
+}
+
 static void
 start (MetaPlugin *plugin)
 {
@@ -385,6 +447,9 @@ start (MetaPlugin *plugin)
 
   on_monitors_changed (monitor_manager, plugin);
 
+  if (meta_is_wayland_compositor ())
+    init_keymap (self);
+
   clutter_actor_show (meta_get_stage_for_display (display));
 }
 
@@ -746,6 +811,15 @@ hide_tile_preview (MetaPlugin *plugin)
   clutter_actor_hide (preview->actor);
 }
 
+static void
+finish_timeline (ClutterTimeline *timeline)
+{
+  g_object_ref (timeline);
+  clutter_timeline_stop (timeline);
+  g_signal_emit_by_name (timeline, "completed", NULL);
+  g_object_unref (timeline);
+}
+
 static void
 kill_switch_workspace (MetaPlugin     *plugin)
 {
@@ -753,9 +827,11 @@ kill_switch_workspace (MetaPlugin     *plugin)
 
   if (priv->tml_switch_workspace1)
     {
+      g_object_ref (priv->tml_switch_workspace1);
       clutter_timeline_stop (priv->tml_switch_workspace1);
       clutter_timeline_stop (priv->tml_switch_workspace2);
       g_signal_emit_by_name (priv->tml_switch_workspace1, "completed", NULL);
+      g_object_unref (priv->tml_switch_workspace1);
     }
 }
 
@@ -768,22 +844,13 @@ kill_window_effects (MetaPlugin      *plugin,
   apriv = get_actor_private (window_actor);
 
   if (apriv->tml_minimize)
-    {
-      clutter_timeline_stop (apriv->tml_minimize);
-      g_signal_emit_by_name (apriv->tml_minimize, "completed", NULL);
-    }
+    finish_timeline (apriv->tml_minimize);
 
   if (apriv->tml_map)
-    {
-      clutter_timeline_stop (apriv->tml_map);
-      g_signal_emit_by_name (apriv->tml_map, "completed", NULL);
-    }
+    finish_timeline (apriv->tml_map);
 
   if (apriv->tml_destroy)
-    {
-      clutter_timeline_stop (apriv->tml_destroy);
-      g_signal_emit_by_name (apriv->tml_destroy, "completed", NULL);
-    }
+    finish_timeline (apriv->tml_destroy);
 }
 
 static const MetaPluginInfo *
