@@ -462,6 +462,10 @@ struct _MetaWindow
    */
   int unmaps_pending;
 
+  /* Number of XReparentWindow requests that we have queued.
+   */
+  int reparents_pending;
+
   /* See docs for meta_window_get_stable_sequence() */
   guint32 stable_sequence;
 
