@@ -27,6 +27,7 @@
 #include "core/display-private.h"
 #include "core/window-private.h"
 #include "wayland/meta-wayland.h"
+#include "wayland/meta-xwayland.h"
 #include "x11/meta-x11-display-private.h"
 
 struct _TestClient {
@@ -69,7 +70,7 @@ ensure_test_client_path (int    argc,
   if (!g_file_test (test_client_path,
                     G_FILE_TEST_EXISTS | G_FILE_TEST_IS_EXECUTABLE))
     {
-      g_autofree char *basename;
+      g_autofree char *basename = NULL;
       g_autofree char *dirname = NULL;
 
       basename = g_path_get_basename (argv[0]);
@@ -92,6 +93,9 @@ test_init (int    *argc,
   g_test_bug_base ("http://bugzilla.gnome.org/show_bug.cgi?id=");
 
   ensure_test_client_path (*argc, *argv);
+
+  meta_wayland_override_display_name ("mutter-test-display");
+  meta_xwayland_override_display_number (512);
 }
 
 AsyncWaiter *
@@ -181,10 +185,12 @@ async_waiter_set_and_wait (AsyncWaiter *waiter)
 }
 
 gboolean
-async_waiter_alarm_filter (AsyncWaiter           *waiter,
-                           MetaX11Display        *x11_display,
-                           XSyncAlarmNotifyEvent *event)
+async_waiter_alarm_filter (MetaX11Display        *x11_display,
+                           XSyncAlarmNotifyEvent *event,
+                           gpointer               data)
 {
+  AsyncWaiter *waiter = data;
+
   if (event->alarm != waiter->alarm)
     return FALSE;
 
@@ -354,12 +360,14 @@ test_client_find_window (TestClient *client,
 }
 
 gboolean
-test_client_alarm_filter (TestClient            *client,
-                          MetaX11Display        *x11_display,
-                          XSyncAlarmNotifyEvent *event)
+test_client_alarm_filter (MetaX11Display        *x11_display,
+                          XSyncAlarmNotifyEvent *event,
+                          gpointer               data)
 {
+  TestClient *client = data;
+
   if (client->waiter)
-    return async_waiter_alarm_filter (client->waiter, x11_display, event);
+    return async_waiter_alarm_filter (x11_display, event, client->waiter);
   else
     return FALSE;
 }
