@@ -36,6 +36,8 @@ typedef struct _MetaWaylandActorSurfacePrivate MetaWaylandActorSurfacePrivate;
 struct _MetaWaylandActorSurfacePrivate
 {
   MetaSurfaceActor *actor;
+
+  gulong actor_destroyed_handler_id;
 };
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MetaWaylandActorSurface,
@@ -51,20 +53,36 @@ meta_wayland_actor_surface_constructed (GObject *object)
 }
 
 static void
-meta_wayland_actor_surface_dispose (GObject *object)
+clear_surface_actor (MetaWaylandActorSurface *actor_surface)
 {
   MetaWaylandActorSurfacePrivate *priv =
-    meta_wayland_actor_surface_get_instance_private (META_WAYLAND_ACTOR_SURFACE (object));
+    meta_wayland_actor_surface_get_instance_private (actor_surface);
+  MetaWaylandSurfaceRole *surface_role =
+    META_WAYLAND_SURFACE_ROLE (actor_surface);
   MetaWaylandSurface *surface =
-    meta_wayland_surface_role_get_surface (META_WAYLAND_SURFACE_ROLE (object));
+    meta_wayland_surface_role_get_surface (surface_role);
+
+  if (!priv->actor)
+    return;
+
+  g_clear_signal_handler (&priv->actor_destroyed_handler_id, priv->actor);
+  g_signal_handlers_disconnect_by_func (priv->actor,
+                                        meta_wayland_surface_notify_geometry_changed,
+                                        surface);
+  g_clear_object (&priv->actor);
+}
+
+static void
+meta_wayland_actor_surface_dispose (GObject *object)
+{
+  MetaWaylandActorSurface *actor_surface = META_WAYLAND_ACTOR_SURFACE (object);
+  MetaWaylandActorSurfacePrivate *priv =
+    meta_wayland_actor_surface_get_instance_private (actor_surface);
 
   if (priv->actor)
     {
-      g_signal_handlers_disconnect_by_func (priv->actor,
-                                            meta_wayland_surface_notify_geometry_changed,
-                                            surface);
       clutter_actor_set_reactive (CLUTTER_ACTOR (priv->actor), FALSE);
-      g_clear_object (&priv->actor);
+      clear_surface_actor (actor_surface);
     }
 
   G_OBJECT_CLASS (meta_wayland_actor_surface_parent_class)->dispose (object);
@@ -92,6 +110,9 @@ meta_wayland_actor_surface_queue_frame_callbacks (MetaWaylandActorSurface *actor
   MetaSurfaceActorWayland *surface_actor_wayland =
     META_SURFACE_ACTOR_WAYLAND (priv->actor);
 
+  if (!priv->actor)
+    return;
+
   meta_surface_actor_wayland_add_frame_callbacks (surface_actor_wayland,
                                                   &pending->frame_callback_list);
   wl_list_init (&pending->frame_callback_list);
@@ -100,25 +121,10 @@ meta_wayland_actor_surface_queue_frame_callbacks (MetaWaylandActorSurface *actor
 double
 meta_wayland_actor_surface_get_geometry_scale (MetaWaylandActorSurface *actor_surface)
 {
-  MetaWaylandSurfaceRole *surface_role =
-    META_WAYLAND_SURFACE_ROLE (actor_surface);
-  MetaWaylandSurface *surface =
-    meta_wayland_surface_role_get_surface (surface_role);
-  MetaWindow *toplevel_window;
+  MetaWaylandActorSurfaceClass *actor_surface_class =
+    META_WAYLAND_ACTOR_SURFACE_GET_CLASS (actor_surface);
 
-  toplevel_window = meta_wayland_surface_get_toplevel_window (surface);
-  if (meta_is_stage_views_scaled ())
-    {
-      return 1;
-    }
-  else
-    {
-      if (!toplevel_window ||
-          toplevel_window->client_type == META_WINDOW_CLIENT_TYPE_X11)
-        return 1;
-      else
-        return meta_window_wayland_get_geometry_scale (toplevel_window);
-    }
+  return actor_surface_class->get_geometry_scale (actor_surface);
 }
 
 static void
@@ -229,6 +235,11 @@ meta_wayland_actor_surface_commit (MetaWaylandSurfaceRole  *surface_role,
 {
   MetaWaylandActorSurface *actor_surface =
     META_WAYLAND_ACTOR_SURFACE (surface_role);
+  MetaWaylandActorSurfacePrivate *priv =
+    meta_wayland_actor_surface_get_instance_private (actor_surface);
+
+  if (!priv->actor)
+    return;
 
   meta_wayland_actor_surface_queue_frame_callbacks (actor_surface, pending);
 
@@ -307,6 +318,13 @@ meta_wayland_actor_surface_get_actor (MetaWaylandActorSurface *actor_surface)
   return priv->actor;
 }
 
+static void
+on_actor_destroyed (ClutterActor            *actor,
+                    MetaWaylandActorSurface *actor_surface)
+{
+  clear_surface_actor (actor_surface);
+}
+
 void
 meta_wayland_actor_surface_reset_actor (MetaWaylandActorSurface *actor_surface)
 {
@@ -315,15 +333,13 @@ meta_wayland_actor_surface_reset_actor (MetaWaylandActorSurface *actor_surface)
   MetaWaylandSurface *surface =
     meta_wayland_surface_role_get_surface (META_WAYLAND_SURFACE_ROLE (actor_surface));
 
-  if (priv->actor)
-    {
-      g_signal_handlers_disconnect_by_func (priv->actor,
-                                            meta_wayland_surface_notify_geometry_changed,
-                                            surface);
-      g_object_unref (priv->actor);
-    }
+  clear_surface_actor (actor_surface);
 
   priv->actor = g_object_ref_sink (meta_surface_actor_wayland_new (surface));
+  priv->actor_destroyed_handler_id =
+    g_signal_connect (priv->actor, "destroy",
+                      G_CALLBACK (on_actor_destroyed),
+                      actor_surface);
 
   g_signal_connect_swapped (priv->actor, "notify::allocation",
                             G_CALLBACK (meta_wayland_surface_notify_geometry_changed),
