@@ -662,8 +662,8 @@ meta_wayland_tablet_tool_get_relative_coordinates (MetaWaylandTabletTool *tool,
   clutter_event_get_coords (event, &xf, &yf);
   meta_wayland_surface_get_relative_coordinates (surface, xf, yf, &xf, &yf);
 
-  *sx = wl_fixed_from_double (xf) / surface->scale;
-  *sy = wl_fixed_from_double (yf) / surface->scale;
+  *sx = wl_fixed_from_double (xf);
+  *sy = wl_fixed_from_double (yf);
 }
 
 static void
